robotpy-romi
============

RobotPy support for the WPILib Romi vendor library.

* Installation instructions can be found in the [RobotPy documentation](https://robotpy.readthedocs.io/en/latest/getting_started.html)
* Documentation at [readthedocs](https://robotpy.readthedocs.io/projects/romi/en/stable/api.html)
* A romi example can be found in our [examples repository](https://github.com/robotpy/examples/tree/main/commands-v2/romi)